"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getQueryFields = exports.getResultFields = void 0;
const sdk_1 = require("@searchkit/sdk");
const version_1 = require("../../version");
function getResultFields(resultFields) {
    const hitFields = Object.keys(resultFields);
    const highlightFields = Object.keys(resultFields).reduce((sum, fieldKey) => {
        const fieldConfiguration = resultFields[fieldKey];
        if (fieldConfiguration.snippet) {
            sum.push(fieldKey);
        }
        return sum;
    }, []);
    return { hitFields, highlightFields };
}
exports.getResultFields = getResultFields;
function getQueryFields(searchFields = {}) {
    return Object.keys(searchFields).map((fieldKey) => {
        const fieldConfiguration = searchFields[fieldKey];
        const weight = `^${fieldConfiguration.weight || 1}`;
        return fieldKey + weight;
    });
}
exports.getQueryFields = getQueryFields;
function isValidDateString(dateString) {
    return typeof dateString === "string" && !isNaN(Date.parse(dateString));
}
function buildConfiguration(state, queryConfig, host, index, apiKey) {
    var _a;
    const { hitFields, highlightFields } = getResultFields(queryConfig.result_fields);
    const queryFields = getQueryFields(queryConfig.search_fields);
    const facets = Object.keys(queryConfig.facets || {}).reduce((sum, facetKey) => {
        var _a;
        const facetConfiguration = queryConfig.facets[facetKey];
        const isDisJunctive = (_a = queryConfig.disjunctiveFacets) === null || _a === void 0 ? void 0 : _a.includes(facetKey);
        if (facetConfiguration.type === "value") {
            sum.push(new sdk_1.RefinementSelectFacet({
                identifier: facetKey,
                field: facetKey,
                label: facetKey,
                size: facetConfiguration.size || 20,
                multipleSelect: isDisJunctive,
                order: facetConfiguration.sort || "count"
            }));
        }
        else if (facetConfiguration.type === "range" &&
            !facetConfiguration.center) {
            sum.push(new sdk_1.MultiQueryOptionsFacet({
                identifier: facetKey,
                field: facetKey,
                label: facetKey,
                multipleSelect: isDisJunctive,
                options: facetConfiguration.ranges.map((range) => {
                    return Object.assign(Object.assign(Object.assign(Object.assign({ label: range.name }, (typeof range.from === "number" ? { min: range.from } : {})), (typeof range.to === "number" ? { max: range.to } : {})), (isValidDateString(range.from)
                        ? { dateMin: range.from.toString() }
                        : {})), (isValidDateString(range.to)
                        ? { dateMax: range.to.toString() }
                        : {}));
                })
            }));
        }
        else if (facetConfiguration.type === "range" &&
            facetConfiguration.center) {
            sum.push(new sdk_1.GeoDistanceOptionsFacet({
                identifier: facetKey,
                field: facetKey,
                label: facetKey,
                multipleSelect: isDisJunctive,
                origin: facetConfiguration.center,
                unit: facetConfiguration.unit,
                ranges: facetConfiguration.ranges.map((range) => {
                    return Object.assign(Object.assign({ label: range.name }, (range.from ? { from: Number(range.from) } : {})), (range.to ? { to: Number(range.to) } : {}));
                })
            }));
        }
        return sum;
    }, []);
    const sortOption = ((_a = state.sortList) === null || _a === void 0 ? void 0 : _a.length) > 0
        ? {
            id: "selectedOption",
            label: "selectedOption",
            field: state.sortList.reduce((acc, s) => {
                acc.push({
                    [s.field]: s.direction
                });
                return acc;
            }, [])
        }
        : { id: "selectedOption", label: "selectedOption", field: "_score" };
    const jsVersion = typeof window !== "undefined" ? "browser" : process.version;
    const metaHeader = `ent=${version_1.LIB_VERSION}-es-connector,js=${jsVersion},t=${version_1.LIB_VERSION}-es-connector,ft=universal`;
    const configuration = {
        host: host,
        index: index,
        connectionOptions: {
            apiKey: apiKey,
            headers: {
                "x-elastic-client-meta": metaHeader
            }
        },
        hits: {
            fields: hitFields,
            highlightedFields: highlightFields
        },
        query: new sdk_1.MultiMatchQuery({
            fields: queryFields
        }),
        sortOptions: [sortOption],
        facets
    };
    return configuration;
}
exports.default = buildConfiguration;
