var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit from "@searchkit/sdk";
import handleRequest from "../index";
const mockSearchkitResponse = {
    summary: {
        query: "test",
        total: 100,
        appliedFilters: [],
        disabledFilters: [],
        sortOptions: []
    },
    hits: {
        page: {
            pageNumber: 0,
            size: 10,
            totalPages: 10,
            total: 100,
            from: 0
        },
        items: [
            {
                id: "test",
                fields: {
                    title: "hello",
                    description: "test"
                },
                highlight: {
                    title: "hello"
                },
                rawHit: {
                    _id: "test"
                }
            }
        ]
    },
    facets: []
};
jest.mock("@searchkit/sdk", () => {
    const originalModule = jest.requireActual("@searchkit/sdk");
    return Object.assign(Object.assign({ __esModule: true }, originalModule), { default: jest.fn((config) => {
            const sk = originalModule.default(config);
            sk.execute = jest.fn(() => mockSearchkitResponse);
            return sk;
        }) });
});
describe("Autocomplete results", () => {
    it("success", () => __awaiter(void 0, void 0, void 0, function* () {
        const state = {
            searchTerm: "test"
        };
        const queryConfig = {
            results: {
                resultsPerPage: 5,
                search_fields: {
                    title: {
                        weight: 2
                    }
                },
                result_fields: {
                    title: {
                        snippet: {
                            size: 100,
                            fallback: true
                        }
                    },
                    nps_link: {
                        raw: {}
                    }
                }
            }
        };
        const results = yield handleRequest({
            state,
            queryConfig,
            host: "http://localhost:9200",
            index: "test",
            connectionOptions: {
                apiKey: "test"
            }
        });
        const searchkitRequestInstance = Searchkit.mock.results[0]
            .value;
        expect(searchkitRequestInstance.execute).toBeCalledWith({
            facets: false,
            hits: { from: 0, includeRawHit: true, size: 5 }
        });
        expect(results).toMatchInlineSnapshot(`
      Object {
        "autocompletedResults": Array [
          Object {
            "_meta": Object {
              "id": "test",
            },
            "description": Object {
              "raw": "test",
            },
            "id": Object {
              "raw": "test",
            },
            "title": Object {
              "raw": "hello",
              "snippet": "hello",
            },
          },
        ],
        "autocompletedSuggestions": undefined,
      }
    `);
    }));
});
